@@ -12,29 +12,29 @@ class QueueProperties(TestCase):
     def setUp(self) -> None:
         """Create a ``DataStore`` instance"""
 
-        self.data_store = AbstractConnector(maxsize=1)
+        self.connector = AbstractConnector(maxsize=1)
 
     def test_size_matches_queue_size(self) -> None:
         """Test the ``size`` method returns the size of the queue`"""
 
-        self.assertEqual(self.data_store.size(), 0)
-        self.data_store._queue.put(1)
-        self.assertEqual(self.data_store.size(), 1)
+        self.assertEqual(self.connector.size(), 0)
+        self.connector._queue.put(1)
+        self.assertEqual(self.connector.size(), 1)
 
     def test_full_state(self) -> None:
         """Test the ``full`` method returns the state of the queue"""
 
-        self.assertFalse(self.data_store.full())
-        self.data_store._queue.put(1)
-        self.assertTrue(self.data_store.full())
+        self.assertFalse(self.connector.full())
+        self.connector._queue.put(1)
+        self.assertTrue(self.connector.full())
 
     def test_empty_state(self) -> None:
         """Test the ``empty`` method returns the state of the queue"""
 
-        self.assertTrue(self.data_store.empty())
-        self.data_store._queue.put(1)
+        self.assertTrue(self.connector.empty())
+        self.connector._queue.put(1)
 
         # The value of Queue.empty() updates asynchronously
         time.sleep(1)
 
-        self.assertFalse(self.data_store.empty())
+        self.assertFalse(self.connector.empty())
